<?php

require_once ('functions.php');

$DEBUG = true;

// log file

$logfile = '../logs/get_grid_data.log';

// start logging 

log_event ("START");
log_parameters ();

// obtain passed-in parameters

$page = $_POST['page']; 		// requested page
$limit = $_POST['rows']; 		// requested number of rows
$sortindex = $_POST['sidx']; 	// requested index row
$sortorder = $_POST['sord']; 	// requested sorting order
	
// sanity check parameters

if ($page == 0) $page = 1;
if ($limit == 0) $limit = 1;
if ($sortindex == '') $sortindex = 'date';
if ($sortorder == '') $sortorder = 'DESC';
	
// count total number of rows
$result = db_count_grid_rows ($totalrows);
log_event ("db_count_grid_rows ($totalrows) = $result");

// calculate the total pages for the query 

if ($totalrows > 0)
{ 
	$totalpages = ceil ($totalrows / $limit); 
	log_event ("totalpages = $totalpages = ceil ($totalrows / $limit)");
} 
else 
{ 
	$totalpages = 0; 
} 

// if the requested page is greater than the total set the requested page to total page 

if ($page > $totalpages) $page = $totalpages;

// calculate the starting position of the rows 

$start = ($limit * $page) - $limit;

// if start position is negative set it to 0 

if ($start < 0) $start = 0; 

// query the database

$result = db_get_grid_data ($sortindex, $sortorder, $start, $limit, $rows);
log_event ("db_get_grid_data ($sortindex, $sortorder, $start, $limit, $rows) = $result");
log_event ("found " . count ($rows) . " rows");
log_event ("totalpages = " . $totalpages);
		
// set the header (This generates an error when you are printing debug messages out)

header ("Last-Modified: " . gmdate( "D, d M Y H:i:s" ) . "GMT" ); 
header ("Cache-Control: no-cache, must-revalidate" ); 
header ("Pragma: no-cache" );
header ("Content-type: text/xml");

// create the XML

$s = "<?xml version='1.0' encoding='utf-8'?>\n";
$s .= "<rows>\n";
$s .= "   <page>" . $page . "</page>\n";
$s .= "   <total>" . count ($rows) . "</total>\n";
$s .= "   <records>" . $totalpages . "</records>\n";

// be sure to put text data in CDATA

foreach ($rows as $row)
{
	$s .= "   <row id=\"" . $row['id'] . "\">\n";
	$s .= "      <cell>" . $row['id'] . "</cell>\n";
	$s .= "      <cell>" . $row['word'] . "</cell>\n";
	$s .= "   </row>\n";
}
$s .= "</rows>\n"; 

echo $s;
log_event ("GENERATED XML DATA:\n$s");

log_event ("END");
log_event ("");

// ------------------------------------------------------------------------------------------------

function log_event ($message)
{
	global $DEBUG;
	global $logfile;
	
	if ($DEBUG)
	{
		$timestamp = date ('Y-m-d H:i:s');
		$arr = $_POST;
		$mode = file_exists ($logfile) ? 'a' : 'x';
		$handle = fopen ($logfile, $mode);
		if ($handle !== false)
		{
			if (count($message) > 0)
			{
				fwrite ($handle, "$timestamp - $message\n") or die ("ERROR: Can't write to file '$logfile'.");
			}
			else
			{
				fwrite ($handle, "\n") or die ("ERROR: Can't write to file '$logfile'.");
			}
			fclose ($handle);
		}
		else
		{
			print "ERROR: Can't open file '$logfile' with mode '$mode'!";
		}
	}
}

// ------------------------------------------------------------------------------------------------

function log_parameters ()
{
	global $DEBUG;
	global $logfile;
	
	if ($DEBUG)
	{
		$timestamp = date ('Y-m-d H:i:s');
		$arr = $_POST;
		$mode = file_exists ($logfile) ? 'a' : 'x';
		$handle = fopen ($logfile, $mode);
		if ($handle !== false)
		{
			fwrite ($handle, "$timestamp - form parameters:\n") or die ("ERROR: Can't write to file '$logfile'.");
			foreach ($arr as $key => $value)
			{
				$toFile = "$timestamp - $key: $value\n";
				fwrite ($handle, $toFile) or die ("ERROR: Can't write to file '$logfile'.");
			}
			fclose ($handle);
		}
		else
		{
			print "ERROR: Can't open file '$logfile' with mode '$mode'!";
		}
	}
}

?>